#!/bin/bash -p
# Copyright 2016,2020 VMware, Inc.  All rights reserved.
#
# This executable loads and unloads the vmioplug.kext.
#

# Test the ownership of a path.
hasOwnership() {
   local path="$1"
   local uid="$2"
   local gid="$3"

   # Numeric IDs are used because some systems have two names (or more)
   # associated with one number.
   set -- `ls -alnd -- "$path" 2>/dev/null`
   [ "$3" = "$uid" -a "$4" = "$gid" ]
}

# To debug, uncomment the next 2 lines.
#set -x
#exec >>/tmp/debug 2>&1

set -e
# This executable runs with root privileges, so hardcode a PATH where
# unprivileged users cannot write.
export PATH=/bin:/sbin:/usr/bin:/usr/sbin

# We might have inherited the umask of the calling user. This executable runs
# with root privileges, so hardcode a reasonable and deterministic umask.
# Was bug 923795.
umask 022

if [ -z "$1" -o -z "$2" ]; then
   # Should be invoked as usbarbService.sh {--start <kext_location> |--stop <kext_location>}
   exit 1
fi

# Main code

case "$1" in
--start)
   if ! hasOwnership "$2" 0 0; then
      KEXT_DIR=`mktemp -d /tmp/usbarbsvc_XXXXXXXX`
      KEXT_LOCATION="$KEXT_DIR"/vmioplug.kext
      cp -r -- "$2" "$KEXT_LOCATION"
      chown -R -- root:wheel "$KEXT_DIR"
   else
      KEXT_LOCATION="$2"
   fi

   kextload "$KEXT_LOCATION"

   if ! hasOwnership "$2" 0 0; then
      rm -rf -- "$KEXT_DIR"
   fi
   ;;

--stop)
   kextunload "$2"
   ;;

*)
   exit 1
esac
